summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJeff Forcier <jeff@bitprophet.org>2017-08-21 19:23:33 -0700
committerJeff Forcier <jeff@bitprophet.org>2017-08-21 19:23:33 -0700
commite841917941aefabc9446e5331ad89dab8328a9b2 (patch)
tree2f9fdb2de1df160ea0d108b345b2b17fdcd1573e
parent419b705e6c9e476fa52fc4eaad79d9b6c365e356 (diff)
downloadparamiko-531-bitprophet-addendum-do-not-delete.tar.gz
Might as well put in params for the rest531-int531-bitprophet-addendum-do-not-delete
-rw-r--r--paramiko/rsacert.py12
1 files changed, 10 insertions, 2 deletions
diff --git a/paramiko/rsacert.py b/paramiko/rsacert.py
index 47741809..056fa844 100644
--- a/paramiko/rsacert.py
+++ b/paramiko/rsacert.py
@@ -58,10 +58,18 @@ class RSACert(RSAKey):
must contain a full certificate and not just a public key.
:param str pkey_filename:
Path to private key file.
:param str pkey_file_obj:
- File-like object containing private key text.
+ File-like object containing private key text. Maps to ``file_obj`` in
+ `.RSAKey`.
+
+ :param str password:
+ Password for unlocking an encrypted private key, if necessary.
+
+ :param key:
+ A manually-created key object (e.g. something created via the
+ Cryptography ``rsa`` module.) Only use if you know what you're doing!
:param str cert_filename:
Path to certificate file.
@@ -58,10 +58,18 @@ class RSACert(RSAKey):
must contain a full certificate and not just a public key.
:param str pkey_filename:
- Path to private key file.
+ Path to private key file. Maps to ``filename`` in `.RSAKey`.
:param str pkey_file_obj: